==> uimaj-2.11.0-source-release.zip: uimaj-2.11.0/uimaj-ep-pear-packager/src/main/java/org/apache/uima/pear/generate/PearExport.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.pear.generate;

import java.io.File;

import org.apache.uima.pear.PearException;

/**
 * A util class for PEAR export operations
 */
public class PearExport {

  /**
   * @param targetFile -
   * @return true -
   * @throws PearException -
   */
  protected boolean ensureTargetFileIsValid(File targetFile) throws PearException {
    if (targetFile.exists() && targetFile.isDirectory()) {
      throw new PearException("The target pear File must not be a directory", new PearException(
              "The target pear File must not be a directory"));
    }
    if (targetFile.exists()) {
      if (!targetFile.canWrite()) {
        throw new PearException("The pear File exists, but is not writable", new PearException(
                "The pear File exists, but is not writable"));
      }
    }
    return true;
  }

}

==> uimaj-3.2.0-source-release.zip: uimaj-3.2.0/uimaj-ep-pear-packager/src/main/java/org/apache/uima/pear/generate/PearExport.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.pear.generate;

import java.io.File;

import org.apache.uima.pear.PearException;


/**
 * A util class for PEAR export operations.
 */
public class PearExport {

  /**
   * Ensure target file is valid.
   *
   * @param targetFile the target file
   * @return true
   * @throws PearException -
   */
  protected boolean ensureTargetFileIsValid(File targetFile) throws PearException {
    if (targetFile.exists() && targetFile.isDirectory()) {
      throw new PearException("The target pear File must not be a directory", new PearException(
              "The target pear File must not be a directory"));
    }
    if (targetFile.exists()) {
      if (!targetFile.canWrite()) {
        throw new PearException("The pear File exists, but is not writable", new PearException(
                "The pear File exists, but is not writable"));
      }
    }
    return true;
  }

}
